local function WLHUD_Chain( object )
	
	-- Setup the metatable
	local T = {}
	setmetatable( T, { __index = function( self, func )
		
		-- Know when to stop chaining
		if func == "__END" then	return object end
		
		-- Otherwise, add the method to the parent object
		return function( self, ... )
			assert( object[func], func .. " missing in object" )
			object[func]( object, ... )
			return self
		end
	end })
	
	-- Return the metatable
	return T
end

function WLHUD_TARGET:Create()
	local WLHUD_TBars_Tex   = "WarLegendHUD/img/tex_tbar_1.dds"
	local WLHUD_Anchor_Tex = "WarLegendHUD/img/anchor.dds"

	WLHUD_TARGET.Anchor = WLHUD_Chain(WINDOW_MANAGER:CreateTopLevelWindow("WLHUD_TARGET.Anchor"))
		:SetDrawLayer(1)
		:SetDimensions(400,100)
		:SetScale(WLHUD_SAVE.Target_Scale)
		:SetAnchor(TOPLEFT, GuiRoot, TOPLEFT, WLHUD_SAVE.Global_X + WLHUD_SAVE.Target_Anchor_X,WLHUD_SAVE.Global_Y + WLHUD_SAVE.Target_Anchor_Y)
		:SetHidden(true)
	.__END

	WLHUD_TARGET.Anchor_BG = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TARGET.Anchor_BG", WLHUD_TARGET.Anchor, CT_BACKDROP))
		:SetCenterColor(1,1,1,0.5)
		:SetEdgeColor(0,0,0,1)
		:SetEdgeTexture("", 8, 1, 1)
		:SetDrawLayer(0)
		:SetAnchorFill(WLHUD_TARGET.Anchor)
		:SetHidden(true)
	.__END

	WLHUD_TARGET.Anchor_Tex = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TARGET.Anchor_Tex", WLHUD_TARGET.Anchor, CT_TEXTURE ))
		:SetDimensions(32,32)
		:SetTexture(WLHUD_Anchor_Tex)
		:SetDrawLayer(2)
		:SetAnchor(TOPLEFT, WLHUD_TARGET.Anchor, TOPLEFT,0,0)
		:SetHidden(true)
	.__END
	
	--[[#############################################################################################################]]--
	--[[ HEALTH ]]--
	--[[#############################################################################################################]]--
	WLHUD_TARGET.HP_Anchor = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TARGET.HP_Anchor", WLHUD_TARGET.Anchor, CT_TEXTURE ))
		:SetDimensions(25,25)
		:SetTexture(WLHUD_Anchor_Tex)
		:SetDrawLayer(4)
		-- :SetAnchor(TOPLEFT, GuiRoot, TOPLEFT, 1300,936)
		:SetAnchor(TOPLEFT, GuiRoot, TOPLEFT, WLHUD_SAVE.Global_X + WLHUD_SAVE.TargetHP_Anchor_X,WLHUD_SAVE.Global_Y + WLHUD_SAVE.TargetHP_Anchor_Y)
		:SetHidden(true)
	.__END

	WLHUD_TARGET.HPB = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TARGET.HPB", WLHUD_TARGET.Anchor, CT_STATUSBAR))
		:SetColor(0.6,0.1,0.1,0.65)
		:SetDrawLayer(2)
		:SetDimensions(WLHUD_SAVE.Target_HPBar_Width,20 + WLHUD_SAVE.TargetHP_Height)
		:SetAnchor(RIGHT, WLHUD_TARGET.HP_Anchor, RIGHT, -155,0)
	.__END
	
	WLHUD_TARGET.HPB_BG = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TARGET.HPB_BG", WLHUD_TARGET.HPB, CT_TEXTURE ))
		:SetDimensions(WLHUD_SAVE.Target_HPBar_Width + 160,55)
		:SetTexture("/esoui/art/miscellaneous/singlelinesection_left.dds")
		:SetDrawLayer(1)
		:SetAnchor(RIGHT, WLHUD_TARGET.HP_Anchor, RIGHT, -30,12)
	.__END
	
	WLHUD_TARGET.HPBT = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TARGET.HPBT", WLHUD_TARGET.HPB, CT_LABEL ))
		:SetFont(WLHUD_SAVE.Bars_Font)
		:SetDrawLayer(4)
		:SetAnchor(LEFT, WLHUD_TARGET.HP_Anchor, LEFT, -120,0)
		:SetScale(WLHUD_SAVE.Bars_Font_Size)
	.__END
	
	WLHUD_TARGET.HPPerc = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TARGET.HPPerc", WLHUD_TARGET.HPB, CT_LABEL ))
		:SetFont(WLHUD_SAVE.Bars_Font)
		:SetDrawLayer(4)
		:SetText("100 %")
		:SetAnchor(LEFT, WLHUD_TARGET.HP_Anchor, LEFT, ((WLHUD_SAVE.Target_HPBar_Width / 350) * WLHUD_SAVE.Target_Perc_X) - 590,0)
		:SetHidden(not WLHUD_SAVE.Enable_Target_HP_Perc)
		:SetScale(WLHUD_SAVE.Bars_Font_Size)
	.__END

	WLHUD_TARGET.HPB_Tex = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TARGET.HPB_Tex", WLHUD_TARGET.HPB, CT_TEXTURE ))
		:SetDimensions(WLHUD_SAVE.Target_HPBar_Width,26 + WLHUD_SAVE.TargetHP_Height)
		:SetTexture(WLHUD_TBars_Tex)
		:SetDrawLayer(4)
		:SetAnchor(RIGHT, WLHUD_TARGET.HP_Anchor, RIGHT, -155,0)
		:SetHidden(not WLHUD_SAVE.TargetHP_Texture)
	.__END

	WLHUD_TARGET.HPB_TexBG = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TARGET.HPB_TexBG", WLHUD_TARGET.HPB, CT_BACKDROP ))
		:SetDimensions(WLHUD_SAVE.Target_HPBar_Width,22 + WLHUD_SAVE.TargetHP_Height)
		:SetCenterColor(0,0,0,1)
		:SetEdgeColor(0,0,0,0)
		:SetEdgeTexture("", 1, 1,0)
		:SetDrawLayer(1)
		:SetAnchor(RIGHT, WLHUD_TARGET.HP_Anchor, RIGHT, -155,0)
	.__END

	--[[#############################################################################################################]]--
	--[[ MAGICKA ]]--
	--[[#############################################################################################################]]--
	-- WLHUD_TARGET.MP_Anchor = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TARGET.MP_Anchor", WLHUD_TARGET.Anchor, CT_TEXTURE ))
	-- 	:SetDimensions(25,25)
	-- 	:SetTexture(WLHUD_Anchor_Tex)
	-- 	:SetDrawLayer(4)
	-- 	:SetAnchor(TOPLEFT, GuiRoot, TOPLEFT, WLHUD_SAVE.Global_X + WLHUD_SAVE.TargetMP_Anchor_X,WLHUD_SAVE.Global_Y + WLHUD_SAVE.TargetMP_Anchor_Y)
	-- 	:SetHidden(true)
	-- .__END

	-- WLHUD_TARGET.MPB = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TARGET.MPB", WLHUD_TARGET.Anchor, CT_STATUSBAR))
	-- 	:SetColor(0.1,0.1,0.6,0.65)
	-- 	:SetDrawLayer(2)
	-- 	:SetDimensions(WLHUD_SAVE.Target_MPBar_Width,20 + WLHUD_SAVE.TargetMP_Height)
	-- 	:SetAnchor(RIGHT, WLHUD_TARGET.MP_Anchor, RIGHT, -155,0)
	-- .__END
	
	-- WLHUD_TARGET.MPB_BG = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TARGET.MPB_BG", WLHUD_TARGET.MPB, CT_TEXTURE ))
	-- 	:SetDimensions(WLHUD_SAVE.Target_MPBar_Width + 150,55)
	-- 	:SetTexture("/esoui/art/miscellaneous/singlelinesection_left.dds")
	-- 	:SetDrawLayer(1)
	-- 	:SetAnchor(RIGHT, WLHUD_TARGET.MP_Anchor, RIGHT, -45,12)
	-- .__END
	
	-- WLHUD_TARGET.MPBT = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TARGET.MPBT", WLHUD_TARGET.MPB, CT_LABEL ))
	-- 	:SetFont(WLHUD_SAVE.Bars_Font)
	-- 	:SetDrawLayer(4)
	-- 	:SetAnchor(LEFT, WLHUD_TARGET.MP_Anchor, LEFT, -120,0)
	-- 	:SetScale(WLHUD_SAVE.Bars_Font_Size)
	-- .__END
	
	-- WLHUD_TARGET.MPPerc = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TARGET.MPPerc", WLHUD_TARGET.Anchor, CT_LABEL ))
	-- 	:SetFont(WLHUD_SAVE.Bars_Font)
	-- 	:SetDrawLayer(4)
	-- 	:SetText("100 %")
	-- 	:SetAnchor(LEFT, WLHUD_TARGET.MP_Anchor, LEFT, ((WLHUD_SAVE.Target_MPBar_Width / 350) * WLHUD_SAVE.Target_Perc_X) - 590,0)
	-- 	:SetHidden(not WLHUD_SAVE.Enable_Target_MP_Perc)
	-- 	:SetScale(WLHUD_SAVE.Bars_Font_Size)
	-- .__END

	-- WLHUD_TARGET.MPB_Tex = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TARGET.MPB_Tex", WLHUD_TARGET.MPB, CT_TEXTURE ))
	-- 	:SetDimensions(WLHUD_SAVE.Target_MPBar_Width,26 + WLHUD_SAVE.TargetMP_Height)
	-- 	:SetTexture(WLHUD_TBars_Tex)
	-- 	:SetDrawLayer(4)
	-- 	:SetAnchor(RIGHT, WLHUD_TARGET.MP_Anchor, RIGHT, -155,0)
	-- .__END

	-- WLHUD_TARGET.MPB_TexBG = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TARGET.MPB_TexBG", WLHUD_TARGET.MPB, CT_BACKDROP ))
	-- 	:SetDimensions(WLHUD_SAVE.Target_MPBar_Width,27 + WLHUD_SAVE.TargetMP_Height)
	-- 	:SetCenterColor(0.13,0.13,0.13,1)
	-- 	:SetEdgeColor(0,0,0,0)
	-- 	:SetEdgeTexture("", 8, 1,0)
	-- 	:SetDrawLayer(1)
	-- 	:SetAnchor(RIGHT, WLHUD_TARGET.MP_Anchor, RIGHT, -155,0)
	-- .__END
	
	--[[#############################################################################################################]]--
	--[[ STAMINA ]]--
	--[[#############################################################################################################]]--
	-- WLHUD_TARGET.SP_Anchor = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TARGET.SP_Anchor", WLHUD_TARGET.Anchor, CT_TEXTURE ))
	-- 	:SetDimensions(25,25)
	-- 	:SetTexture(WLHUD_Anchor_Tex)
	-- 	:SetDrawLayer(4)
	-- 	:SetAnchor(TOPLEFT, GuiRoot, TOPLEFT, WLHUD_SAVE.Global_X + WLHUD_SAVE.TargetSP_Anchor_X,WLHUD_SAVE.Global_Y + WLHUD_SAVE.TargetSP_Anchor_Y)
	-- 	:SetHidden(true)
	-- .__END

	-- WLHUD_TARGET.SPB = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TARGET.SPB", WLHUD_TARGET.Anchor, CT_STATUSBAR))
	-- 	:SetColor(0.1,0.6,0.1,0.65)
	-- 	:SetDrawLayer(2)
	-- 	:SetDimensions(WLHUD_SAVE.Target_SPBar_Width,20 + WLHUD_SAVE.TargetSP_Height)
	-- 	:SetAnchor(RIGHT, WLHUD_TARGET.SP_Anchor, RIGHT, -155,0)
	-- .__END
	
	-- WLHUD_TARGET.SPB_BG = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TARGET.SPB_BG", WLHUD_TARGET.SPB, CT_TEXTURE ))
	-- 	:SetDimensions(WLHUD_SAVE.Target_SPBar_Width + 150,55)
	-- 	:SetTexture("/esoui/art/miscellaneous/singlelinesection_left.dds")
	-- 	:SetDrawLayer(1)
	-- 	:SetAnchor(RIGHT, WLHUD_TARGET.SP_Anchor, RIGHT, -45,12)
	-- .__END
	
	-- WLHUD_TARGET.SPBT = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TARGET.SPBT", WLHUD_TARGET.SPB, CT_LABEL ))
	-- 	:SetFont(WLHUD_SAVE.Bars_Font)
	-- 	:SetDrawLayer(4)
	-- 	:SetAnchor(LEFT, WLHUD_TARGET.SP_Anchor, LEFT, -120,0)
	-- 	:SetScale(WLHUD_SAVE.Bars_Font_Size)
	-- .__END
	
	-- WLHUD_TARGET.SPPerc = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TARGET.SPPerc", WLHUD_TARGET.Anchor, CT_LABEL ))
	-- 	:SetFont(WLHUD_SAVE.Bars_Font)
	-- 	:SetDrawLayer(4)
	-- 	:SetText("100 %")
	-- 	:SetAnchor(LEFT, WLHUD_TARGET.SP_Anchor, LEFT, ((WLHUD_SAVE.Target_SPBar_Width / 350) * WLHUD_SAVE.Target_Perc_X) - 590,0)
	-- 	:SetHidden(not WLHUD_SAVE.Enable_Target_SP_Perc)
	-- 	:SetScale(WLHUD_SAVE.Bars_Font_Size)
	-- .__END

	-- WLHUD_TARGET.SPB_Tex = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TARGET.SPB_Tex", WLHUD_TARGET.SPB, CT_TEXTURE ))
	-- 	:SetDimensions(WLHUD_SAVE.Target_SPBar_Width,26 + WLHUD_SAVE.TargetSP_Height)
	-- 	:SetTexture(WLHUD_TBars_Tex)
	-- 	:SetDrawLayer(4)
	-- 	:SetAnchor(RIGHT, WLHUD_TARGET.SP_Anchor, RIGHT, -155,0)
	-- .__END

	-- WLHUD_TARGET.SPB_TexBG = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TARGET.SPB_TexBG", WLHUD_TARGET.SPB, CT_BACKDROP ))
	-- 	:SetDimensions(WLHUD_SAVE.Target_SPBar_Width,27 + WLHUD_SAVE.TargetSP_Height)
	-- 	:SetCenterColor(0.13,0.13,0.13,1)
	-- 	:SetEdgeColor(0,0,0,0)
	-- 	:SetEdgeTexture("", 8, 1,0)
	-- 	:SetDrawLayer(1)
	-- 	:SetAnchor(RIGHT, WLHUD_TARGET.SP_Anchor, RIGHT, -155,0)
	-- .__END

	--[[#############################################################################################################]]--
	--[[ LABELS ]]--
	--[[#############################################################################################################]]--
	WLHUD_TARGET.LBL = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TARGET.LBL", WLHUD_TARGET.HPB, CT_LABEL ))
		:SetFont(WLHUD_SAVE.Bars_Font)
		:SetDrawLayer(4)
		:SetDimensions(260 * (WLHUD_SAVE.Target_LBL_Width / 350),25)
		:SetScale(WLHUD_SAVE.Bars_Font_Size)
	.__END

	WLHUD_TARGET.Class = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TARGET.Class", WLHUD_TARGET.HPB, CT_LABEL ))
		:SetFont(WLHUD_SAVE.Bars_Font)
		:SetDrawLayer(4)
		:SetDimensions(260 * (WLHUD_SAVE.Target_LBL_Width / 350),120)
		:SetScale(WLHUD_SAVE.Bars_Font_Size)
	.__END
	
	WLHUD_TARGET.LVL = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TARGET.LVL", WLHUD_TARGET.HPB, CT_LABEL ))
		:SetFont(WLHUD_SAVE.Bars_Font)
		:SetDrawLayer(4)
		:SetScale(WLHUD_SAVE.Bars_Font_Size)
	.__END
	
	WLHUD_TARGET.AllyTex = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TARGET.AllyTex", WLHUD_TARGET.HPB, CT_TEXTURE ))
		:SetDimensions(32,64)
		:SetDrawLayer(1)
		:SetHidden(true)
	.__END
	
	WLHUD_TARGET.Elite1 = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TARGET.Elite1", WLHUD_TARGET.HPB, CT_TEXTURE ))
		:SetColor(1,1,1,1)
		:SetDimensions(32,32)
		:SetDrawLayer(3)
		:SetTexture("/esoui/art/progression/icon_dualwield.dds")
		:SetHidden(true)
	.__END
	
	WLHUD_TARGET.Elite2 = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TARGET.Elite2", WLHUD_TARGET.Elite1, CT_TEXTURE ))
		:SetColor(0.7,0.7,0.7,1)
		:SetDimensions(32,32)
		:SetDrawLayer(2)
		:SetTexture("/esoui/art/progression/icon_dualwield.dds")
		:SetHidden(true)
	.__END
	
	WLHUD_TARGET.Elite3 = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TARGET.Elite3", WLHUD_TARGET.Elite1, CT_TEXTURE ))
		:SetColor(0.4,0.4,0.4,1)
		:SetDimensions(32,32)
		:SetDrawLayer(1)
		:SetTexture("/esoui/art/progression/icon_dualwield.dds")
		:SetHidden(true)
	.__END

	WLHUD_TARGET.Distance = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TARGET.Distance", WLHUD_TARGET.HPB, CT_LABEL ))
		:SetFont(WLHUD_SAVE.Bars_Font)
		:SetDrawLayer(1)
		-- :SetHidden(true)
		:SetAnchor(BOTTOMLEFT, GuiRoot, CENTER, 50,0)
		-- :SetText("10")
	.__END
end --WLHUD_TARGET:Create()

-- function WLHUD_TARGET:Create_Buffs()
-- 	WLHUD_TARGET.Buff_MW = WLHUD_Chain(WINDOW_MANAGER:CreateTopLevelWindow("WLHUD_TARGET_Buff_MW"))
-- 		:SetAnchor(TOPLEFT,GuiRoot,TOPLEFT, WLHUD_SAVE.Global_X + WLHUD_SAVE.TargetBuffs_X,WLHUD_SAVE.Global_Y + WLHUD_SAVE.TargetBuffs_Y)
-- 		:SetDimensions(300, 44)
-- 		:SetScale(WLHUD_SAVE.TBuff_Scale)
-- 	.__END
	
-- 	WLHUD_TARGET.Buff_BG = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TARGET.Buff_BG", WLHUD_TARGET.Buff_MW, CT_BACKDROP))
-- 		:SetCenterColor(0.13, 0.8, 0.13, 0.25)
-- 		:SetEdgeColor(0.13, 0.6, 0.13, 1)
-- 		:SetEdgeTexture("", 8, 1, 1)
-- 		:SetDrawLayer(1)
-- 		:SetAnchorFill(WLHUD_TARGET.Buff_MW)
-- 		:SetHidden(true)
-- 	.__END
	
-- 	WLHUD_TARGET.Buff_MW_LBL = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TARGET.Buff_MW_LBL", WLHUD_TARGET.Buff_MW, CT_LABEL ))
-- 		:SetColor(0.13, 0.8, 0.13, 1)
-- 		:SetFont(WLHUD_SAVE.Bars_Font)
-- 		:SetDrawLayer(4)
-- 		:SetText(WLHUD_TARGET.Buff_MW_Text)
-- 		:SetAnchor(CENTER, WLHUD_TARGET.Buff_MW, CENTER, 0,0)
-- 		:SetHidden(true)
-- 	.__END

-- 	WLHUD_TARGET.Buff_Anchor = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TARGET.Buff_Anchor", WLHUD_TARGET.Buff_BG, CT_TEXTURE ))
-- 		:SetDimensions(25,25)
-- 		:SetTexture(WLHUD_Anchor_Tex)
-- 		:SetDrawLayer(4)
-- 		:SetAnchor(TOPLEFT, WLHUD_TARGET.Buff_BG, TOPLEFT, 5,5)
-- 		:SetHidden(true)
-- 	.__END
	
-- 	WLHUD_TARGET.DeBuff_MW = WLHUD_Chain(WINDOW_MANAGER:CreateTopLevelWindow("WLHUD_TARGET_DeBuff_MW"))
-- 		:SetAnchor(TOPLEFT,GuiRoot,TOPLEFT, WLHUD_SAVE.Global_X + WLHUD_SAVE.TargetDEBuffs_X,WLHUD_SAVE.Global_Y + WLHUD_SAVE.TargetDEBuffs_Y)
-- 		:SetDimensions(300, 44)
-- 		:SetScale(WLHUD_SAVE.TDEBuff_Scale)
-- 	.__END
	
-- 	WLHUD_TARGET.DeBuff_BG = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TARGET.DeBuff_BG", WLHUD_TARGET.DeBuff_MW, CT_BACKDROP))
-- 		:SetCenterColor(0.6, 0.13, 0.13, 0.25)
-- 		:SetEdgeColor(0.8, 0.13, 0.13, 1)
-- 		:SetEdgeTexture("", 8, 1, 1)
-- 		:SetDrawLayer(1)
-- 		:SetAnchorFill(WLHUD_TARGET.DeBuff_MW)
-- 		:SetHidden(true)
-- 	.__END
	
-- 	WLHUD_TARGET.DeBuff_MW_LBL = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TARGET.DeBuff_MW_LBL", WLHUD_TARGET.DeBuff_MW, CT_LABEL ))
-- 		:SetColor(0.8, 0.13, 0.13, 1)
-- 		:SetFont(WLHUD_SAVE.Bars_Font)
-- 		:SetDrawLayer(4)
-- 		:SetText(WLHUD_TARGET.DeBuff_MW_Text)
-- 		:SetAnchor(CENTER, WLHUD_TARGET.DeBuff_MW, CENTER, 0,0)
-- 		:SetHidden(true)
-- 	.__END

-- 	WLHUD_TARGET.DeBuff_Anchor = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TARGET.DeBuff_Anchor", WLHUD_TARGET.DeBuff_BG, CT_TEXTURE ))
-- 		:SetDimensions(25,25)
-- 		:SetTexture(WLHUD_Anchor_Tex)
-- 		:SetDrawLayer(4)
-- 		:SetAnchor(TOPLEFT, WLHUD_TARGET.DeBuff_BG, TOPLEFT, 5,5)
-- 		:SetHidden(true)
-- 	.__END

-- 	--[[#############################################################################################################]]--
-- 	--[[ PREVIEW ]]--
-- 	--[[#############################################################################################################]]--
-- 	WLHUD_T_PreviewBuff_MW = WLHUD_Chain(WINDOW_MANAGER:CreateTopLevelWindow("WLHUD_T_PreviewBuff_MW"))
-- 		:SetAnchor(TOPLEFT,GuiRoot,TOPLEFT, WLHUD_SAVE.Global_X + WLHUD_SAVE.TargetBuffs_X,WLHUD_SAVE.Global_Y + WLHUD_SAVE.TargetBuffs_Y)
-- 		:SetDimensions(300, 44)
-- 		:SetScale(WLHUD_SAVE.TBuff_Scale)
-- 		:SetHidden(true)
-- 	.__END

-- 	WLHUD_TBuff_PreviewBG = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TBuff_PreviewBG", WLHUD_T_PreviewBuff_MW, CT_BACKDROP ))
-- 		:SetDimensions(44,44)
-- 		:SetDrawLayer(1)
-- 		:SetAnchor(TOPLEFT, WLHUD_TARGET.Buff_MW, TOPLEFT, 2, 3)
-- 		:SetEdgeTexture("", 8, 1, 3)
-- 		:SetEdgeColor(WLHUD_SAVE.TBuff_BG_R, WLHUD_SAVE.TBuff_BG_G, WLHUD_SAVE.TBuff_BG_B,1)
-- 		:SetCenterColor(0.13,0.13,0.13,1)
-- 	.__END
	
-- 	WLHUD_TBuff_Preview = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TBuff_Preview", WLHUD_TBuff_PreviewBG, CT_TEXTURE ))
-- 		:SetColor(1,1,1,1)
-- 		:SetDimensions(36,36)
-- 		:SetDrawLayer(3)
-- 		:SetTexture("/esoui/art/icons/ability_sorcerer_038.dds")
-- 		:SetAnchor(CENTER, WLHUD_TBuff_PreviewBG, CENTER, 0, 0)
-- 	.__END

-- 	WLHUD_TBuff_Preview_LBL = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TBuff_Preview_LVL", WLHUD_TBuff_PreviewBG, CT_LABEL ))
-- 		:SetFont("ZoFontBossName")
-- 		:SetDimensions(45,25)
-- 		:SetDrawLayer(4)
-- 		:SetAnchor(BOTTOM, WLHUD_TBuff_PreviewBG, BOTTOM, 5,25)
-- 		:SetColor(WLHUD_SAVE.TBuff_R, WLHUD_SAVE.TBuff_G, WLHUD_SAVE.TBuff_B, 1)
-- 	.__END

-- 	WLHUD_T_PreviewDEBuff_MW = WLHUD_Chain(WINDOW_MANAGER:CreateTopLevelWindow("WLHUD_T_PreviewDEBuff_MW"))
-- 		:SetAnchor(TOPLEFT,GuiRoot,TOPLEFT, WLHUD_SAVE.Global_X + WLHUD_SAVE.TargetDEBuffs_X,WLHUD_SAVE.Global_Y + WLHUD_SAVE.TargetDEBuffs_Y)
-- 		:SetDimensions(300, 44)
-- 		:SetScale(WLHUD_SAVE.TDEBuff_Scale)
-- 		:SetHidden(true)
-- 	.__END
	
-- 	WLHUD_TDEBuff_PreviewBG = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TDEBuff_PreviewBG", WLHUD_T_PreviewDEBuff_MW, CT_BACKDROP ))
-- 		:SetDimensions(44,44)
-- 		:SetDrawLayer(1)
-- 		:SetAnchor(TOPLEFT, WLHUD_TARGET.DeBuff_MW, TOPLEFT, 2, 3)
-- 		:SetEdgeTexture("", 8, 1, 3)
-- 		:SetEdgeColor(WLHUD_SAVE.TDEBuff_BG_R, WLHUD_SAVE.TDEBuff_BG_G, WLHUD_SAVE.TDEBuff_BG_B,1)
-- 		:SetCenterColor(0.13,0.13,0.13,1)
-- 	.__END
	
-- 	WLHUD_TDEBuff_Preview = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TDEBuff_Preview", WLHUD_TDEBuff_PreviewBG, CT_TEXTURE ))
-- 		:SetColor(1,1,1,1)
-- 		:SetDimensions(36,36)
-- 		:SetDrawLayer(3)
-- 		:SetTexture("/esoui/art/icons/ability_1handed_002.dds")
-- 		:SetAnchor(CENTER, WLHUD_TDEBuff_PreviewBG, CENTER, 0, 0)
-- 	.__END

-- 	WLHUD_TDEBuff_Preview_LBL = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TDEBuff_Preview_LBL", WLHUD_TDEBuff_PreviewBG, CT_LABEL ))
-- 		:SetFont("ZoFontBossName")
-- 		:SetDimensions(45,25)
-- 		:SetDrawLayer(4)
-- 		:SetAnchor(BOTTOM, WLHUD_TDEBuff_PreviewBG, BOTTOM, 5,25)
-- 		:SetColor(WLHUD_SAVE.TDEBuff_R, WLHUD_SAVE.TDEBuff_G, WLHUD_SAVE.TDEBuff_B, 1)
-- 	.__END
-- end --WLHUD_TARGET:Create_Buffs()

-- function WLHUD_TARGET:Create_CastBar()
-- 	WLHUD_TargetCastAnchor = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TargetCastAnchor", WLHUD_TARGET.Anchor, CT_BACKDROP))
-- 		:SetCenterColor(0.6, 0.13, 0.13, 0)
-- 		:SetEdgeColor(0.8, 0.13, 0.13, 0)
-- 		:SetEdgeTexture("", 8, 1, 0)
-- 		:SetDrawLayer(1)
-- 		:SetDimensions(350,20)
-- 		:SetAnchor(CENTER,WLHUD_TARGET.Anchor,CENTER, 0,12)
-- 	.__END
	
-- 	WLHUD_TargetCast_Bar = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TargetCast_Bar", WLHUD_TargetCastAnchor, CT_STATUSBAR))
-- 		:SetDrawLayer(3)
-- 		:SetDimensions(WLHUD_SAVE.Target_LBL_Width, 20)
-- 		:SetAnchor(TOPLEFT, WLHUD_TargetCastAnchor, TOPLEFT, 350 - WLHUD_SAVE.Target_LBL_Width,0)
-- 	.__END
	
-- 	WLHUD_TARGET.CastLBL = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TARGET.CastLBL", WLHUD_TargetCastAnchor, CT_LABEL ))
-- 		:SetFont("ZoFontAnnounceSmall")
-- 		:SetDrawLayer(4)
-- 		:SetAnchor(TOPLEFT, WLHUD_TargetCastAnchor, TOPLEFT, 355,0)
-- 		:SetDimensions(110, 20)
-- 		:SetScale(WLHUD_SAVE.Bars_Font_Size)
-- 	.__END

-- 	WLHUD_TARGET.Cast_BG = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TARGET.Cast_BG", WLHUD_TargetCastAnchor, CT_TEXTURE ))
-- 		:SetDimensions(WLHUD_SAVE.Target_LBL_Width,55)
-- 		:SetTexture("/esoui/art/miscellaneous/singlelinesection_left.dds")
-- 		:SetDrawLayer(2)
-- 		:SetAnchor(TOPLEFT, WLHUD_TargetCastAnchor, TOPLEFT, 350 - WLHUD_SAVE.Target_LBL_Width,-4)
-- 	.__END
	
-- 	WLHUD_TARGET.CastReact = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TARGET.CastReact", WLHUD_TargetCastAnchor, CT_LABEL ))
-- 		:SetFont("ZoFontAnnounceSmall")
-- 		:SetDrawLayer(4)
-- 		:SetAnchor(TOP, WLHUD_TARGET.Cast_BG, TOP, 0,0)
-- 		:SetScale(WLHUD_SAVE.Bars_Font_Size)
-- 	.__END
-- end --WLHUD_TARGET:Create_CastBar()

function WLHUD_TARGET:Create_Shield()
	WLHUD_TARGET.Shield = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TARGET.Shield", WLHUD_TARGET.Anchor, CT_LABEL ))
		:SetFont("ZoFontAnnounceSmall")
		:SetDrawLayer(4)
		:SetAnchor(BOTTOMRIGHT, WLHUD_TARGET.HP_Anchor, TOP, 0,0)
		:SetText(WLHUD_PLAYER.ShieldText)
		:SetHidden(true)
	.__END
	
	WLHUD_TARGET.Shield_Value = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TARGET.Shield_Value", WLHUD_TARGET.Anchor, CT_LABEL ))
		:SetFont(WLHUD_SAVE.Bars_Font)
		:SetDrawLayer(4)
		:SetAnchor(BOTTOMRIGHT, WLHUD_TARGET.HP_Anchor, TOP, 50,0)
		:SetColor(0.901,0.494,0.188, 1)
		:SetText("550")
		:SetHidden(true)
	.__END

	WLHUD_TargetShield_Bar = WLHUD_Chain(WINDOW_MANAGER:CreateControl("WLHUD_TargetShield_Bar", WLHUD_TARGET.Anchor, CT_STATUSBAR))
		:SetDrawLayer(3)
		:SetDimensions(0, 15)
		:SetAnchor(TOPLEFT, WLHUD_TARGET.HPB_BG, TOPLEFT, 40,110)
		:SetGradientColors(0.300,0.800,0.900,0.58, 0.300,0.800,0.900,1)
		:SetHidden(true)
	.__END
end --WLHUD_TARGET:Create_Shield()