local function WLHUD_Chain( object )
	
	-- Setup the metatable
	local T = {}
	setmetatable( T, { __index = function( self, func )
		
		-- Know when to stop chaining
		if func == "__END" then	return object end
		
		-- Otherwise, add the method to the parent object
		return function( self, ... )
			assert( object[func], func .. " missing in object" )
			object[func]( object, ... )
			return self
		end
	end })
	
	-- Return the metatable
	return T
end

function WLHUD_RIGHT_CLICK:Create_RightClick()
	local control	 = WLHUD_RIGHT_CLICK
	local addon	   	 = "WLHUD"
	local edge_tex 	 = "EsoUI/Art/Tooltips/UI-Border.dds"
	local center_tex = "EsoUI/Art/Tooltips/UI-TooltipCenter.dds"
	local owner      = "RightClick"

	control[addon.."_RC_MW"] = WLHUD_Chain(WINDOW_MANAGER:CreateTopLevelWindow("WLRC_"..addon))
	.__END

	control[owner] = WLHUD_Chain(WINDOW_MANAGER:CreateControl(addon.."_RIGHT_CLICK_CT_"..owner, control[addon.."_RC_MW"], CT_CONTROL))
		:SetDimensions(WLHUD_SAVE.Player_HPBar_Width + 140,20 + WLHUD_SAVE.PlayerHP_Height)
		:SetMouseEnabled(true)
		:SetAnchor(TOPLEFT, WLHUD_PLAYER.HP_Anchor, TOPLEFT, 25,0)
		:SetHandler("OnMouseUp", function(self, button) control:OnMouseUp(_, button, control, owner) end)
	.__END

	control["_BG_"..owner] = WLHUD_Chain(WINDOW_MANAGER:CreateControl(addon.."_RIGHT_CLICK_BG_"..owner, control[addon.."_RC_MW"], CT_BACKDROP))
		:SetDimensions(200,100)
		:SetCenterTexture(center_tex)
		:SetEdgeTexture(edge_tex, 128, 16)
		:SetInsets(16,16,-16,-16)
		:SetHidden(true)
		-- :SetDrawLayer(0)
	.__END

	control["_HIGHLIGHT_"..owner] = WLHUD_Chain(WINDOW_MANAGER:CreateControl(addon.."_HIGHLIGHT_"..owner, control["_BG_"..owner], CT_TEXTURE))
		:SetTexture("EsoUI/Art/Miscellaneous/highlightOverlay_center.dds")
		:SetDimensions(190,30)
		:SetDrawLayer(1)
		:SetHidden(true)
	.__END

	control["_LEAVE_"..owner] = WLHUD_Chain(WINDOW_MANAGER:CreateControl(addon.."_LEAVE_"..owner, control["_BG_"..owner], CT_BUTTON))
		:SetDimensions(230,25)
		:SetAnchor(TOPLEFT, control["_BG_"..owner] ,TOPLEFT, 10,35)
		:SetFont("ZoFontAnnounceMedium")
		:SetText("Leave Party")
		:SetDrawLayer(3)
		:SetScale(0.80)
		:SetNormalFontColor(197/255, 194/255, 158/255, 1)
		:SetMouseOverFontColor(1,1,1,1)
		:SetHorizontalAlignment(MIDDLE)
		:SetHandler("OnClicked", function(self) GroupLeave() control["_BG_"..owner]:SetHidden(true) control:Def_ZO_DisplayName(control) end)
		:SetHandler("OnMouseEnter", function(self) control:MoveHilight(control, owner, "_LEAVE_") end)
		:SetHandler("OnMouseExit", function(self) control["_HIGHLIGHT_"..owner]:SetHidden(true) end)
	.__END

	control["_DISBAND_"..owner] = WLHUD_Chain(WINDOW_MANAGER:CreateControl(addon.."_DISBAND_"..owner, control["_BG_"..owner], CT_BUTTON))
		:SetDimensions(230,25)
		:SetAnchor(TOPLEFT, control["_BG_"..owner] ,TOPLEFT, 10,65)
		:SetFont("ZoFontAnnounceMedium")
		:SetText("Disband Party")
		:SetDrawLayer(3)
		:SetScale(0.80)
		:SetNormalFontColor(197/255, 194/255, 158/255, 1)
		:SetMouseOverFontColor(1,1,1,1)
		:SetHorizontalAlignment(MIDDLE)
		:SetHandler("OnClicked", function(self) GroupDisband() control["_BG_"..owner]:SetHidden(true) control:Def_ZO_DisplayName(control) d("You disdanded your party.") end)
		:SetHandler("OnMouseEnter", function(self) control:MoveHilight(control, owner, "_DISBAND_") end)
		:SetHandler("OnMouseExit", function(self) control["_HIGHLIGHT_"..owner]:SetHidden(true) end)
	.__END

	control["_LOGOUT_"..owner] = WLHUD_Chain(WINDOW_MANAGER:CreateControl(addon.."_LOGOUT_"..owner, control["_BG_"..owner], CT_BUTTON))
		:SetDimensions(125,25)
		:SetAnchor(BOTTOMLEFT, control["_BG_"..owner] ,BOTTOMLEFT, 10,-10)
		:SetFont("ZoFontAnnounceMedium")
		:SetText("Log Out")
		:SetDrawLayer(3)
		:SetScale(0.65)
		:SetNormalFontColor(197/255, 194/255, 158/255, 1)
		:SetMouseOverFontColor(1,0.13,0.13,1)
		:SetHorizontalAlignment(MIDDLE)
		:SetHandler("OnClicked", function(self) Logout() control["_BG_"..owner]:SetHidden(true) control:Def_ZO_DisplayName(control) end)
	.__END
end --WLHUD_PLAYER:Create_RightClick()

function WLHUD_RIGHT_CLICK:OnMouseUp(_, button, control, owner)
	if (Loaded == false) then return end

	if (button == 2) then
		control:Toggle_RC(control, owner)
	else
		control["_BG_"..owner]:SetHidden(true)

		if (control["ZO_DisplayName_TOP"] ~= nil) then
			ZO_DisplayName:SetAnchor(TOPLEFT, GuiRoot, TOPLEFT, control["ZO_DisplayName_LEFT"],control["ZO_DisplayName_TOP"])
			ZO_DisplayName:SetHidden(true)
		end
	end
end --WLHUD_RIGHT_CLICK:OnMouseUp()

function WLHUD_RIGHT_CLICK:MoveHilight(control, owner, item)
	control["_HIGHLIGHT_"..owner]:SetHidden(false)
	control["_HIGHLIGHT_"..owner]:SetAnchor(LEFT, control[item..owner], LEFT, -8,0)
end --WLHUD_RIGHT_CLICK:MoveHilight()

function WLHUD_RIGHT_CLICK:Toggle_RC(control, owner)
	local numOption = 2
	local mouseTop, mouseLeft = GuiMouse:GetTop(), GuiMouse:GetLeft()

	if (control["_BG_"..owner]:IsHidden()) then

		control["ZO_DisplayName_TOP"], control["ZO_DisplayName_LEFT"] = ZO_DisplayName:GetTop(), ZO_DisplayName:GetLeft()

		control["_BG_"..owner]:SetAnchor(BOTTOMLEFT, GuiRoot, TOPLEFT, mouseLeft,mouseTop)
		control["_BG_"..owner]:SetHidden(false)

		if (GetGroupSize() > 1) then
			numOption = numOption + 1
			control["_LEAVE_"..owner]:SetHidden(false)
		else
			control["_LEAVE_"..owner]:SetHidden(true)
		end

		if (IsUnitGroupLeader("player")) then
			numOption = numOption + 1
			control["_DISBAND_"..owner]:SetHidden(false)
		else
			control["_DISBAND_"..owner]:SetHidden(true)
		end

		control["_BG_"..owner]:SetHeight(numOption * 35)

		ZO_DisplayName:SetHidden(false)
		ZO_DisplayName:SetAnchor(TOPLEFT, control["_BG_"..owner], TOPLEFT, 5,5)
		ZO_DisplayName:SetDrawLayer(4)
	else
		control["_BG_"..owner]:SetAnchor(BOTTOMLEFT, GuiRoot, TOPLEFT, mouseLeft,mouseTop)
	end
end --WLHUD_RIGHT_CLICK:Toggle_RC()

function WLHUD_RIGHT_CLICK:Def_ZO_DisplayName(control)
	ZO_DisplayName:SetAnchor(TOPLEFT, GuiRoot, TOPLEFT, control["ZO_DisplayName_LEFT"],control["ZO_DisplayName_TOP"])
	ZO_DisplayName:SetHidden(true)
end